@@ -13,12 +13,10 @@
 #![cfg_attr(test, deny(warnings))]
 #![cfg_attr(all(test, feature = "unstable"), feature(test, filling_drop))]
 #![cfg_attr(feature = "unstable", feature(unsafe_no_drop_flag))]
-#![cfg_attr(feature = "heap_size", feature(plugin, custom_derive))]
-#![cfg_attr(feature = "heap_size", plugin(heapsize_plugin))]
 
 #[cfg(all(test, feature = "unstable"))] extern crate test;
 #[cfg(feature = "log-events")] extern crate rustc_serialize;
-#[cfg(feature = "heap_size")] extern crate heapsize;
+#[cfg(feature = "heapsize")] #[macro_use] extern crate heapsize;
 #[cfg(test)] extern crate rand;
 #[macro_use] extern crate lazy_static;
 #[macro_use] extern crate debug_unreachable;
