@@ -134,6 +134,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "alink",
     "alphabetic",
     "alt",
+    "alternate",
     "altglyph",
     "altGlyph",
     "altglyphdef",
@@ -155,6 +156,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "annotation",
     "annotation-xml",
     "anonymous",
+    "apple-touch-icon",
     "apply",
     "approx",
     "arabic-form",
@@ -1123,6 +1125,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "stroke-opacity",
     "stroke-width",
     "strong",
+    "stylesheet",
     "sub",
     "submit",
     "subscriptshift",
